@@ -9,9 +9,11 @@ from .utils import validator
 
 
 def _iana_tld():
-    """Load IANA TLDs."""
+    """Load IANA TLDs as a Generator."""
     with Path(__file__).parent.joinpath("_tld.txt").open() as tld_f:
-        return (line.strip() for line in tld_f.readlines()[1:])
+        _ = next(tld_f)  # ignore the first line
+        for line in tld_f:
+            yield line.strip()
 
 
 @validator
@@ -57,17 +59,21 @@ def domain(
         return False
 
     try:
-        return not re.search(r"\s", value) and re.match(
+
+        service_record = r"_" if rfc_2782 else ""
+        trailing_dot = r"\.?$" if rfc_1034 else r"$"
+
+        return not re.search(r"\s|__+", value) and re.match(
             # First character of the domain
-            rf"^(?:[a-z0-9{r'_?'if rfc_2782 else ''}]"
+            rf"^(?:[a-z0-9{service_record}]"
             # Sub-domain
-            + rf"(?:[a-z0-9-{r'_?'if rfc_2782 else ''}]{{0,61}}"
+            + rf"(?:[a-z0-9-{service_record}]{{0,61}}"
             # Hostname
-            + rf"[a-z0-9{r'_?'if rfc_2782 else ''}])?\.)"
+            + rf"[a-z0-9{service_record}])?\.)"
             # First 61 characters of the gTLD
             + r"+[a-z0-9][a-z0-9-_]{0,61}"
             # Last character of the gTLD
-            + rf"[a-z]{r'.?$' if rfc_1034 else r'$'}",
+            + rf"[a-z]{trailing_dot}",
             value.encode("idna").decode("utf-8"),
             re.IGNORECASE,
         )
